@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2011, 2013, 2017-2018 Samuel Thibault <samuel.thibault@ens-lyon.org>
+ *  Copyright (C) 2004, 2011, 2013, 2017-2018, 2020 Samuel Thibault <samuel.thibault@ens-lyon.org>
  *
  * This program is free software ; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -68,7 +68,7 @@ extern int fxt_fdwrite(fxt_t fxt, int fd);
 extern int fxt_fdwritetime(fxt_t fxt, int fd);
 extern int fxt_fdevents_start(fxt_t fxt, int fd, int kind);
 extern int fxt_fdevents_stop(fxt_t fxt, int fd);
-extern int fxt_setupeventsbuffer(fxt_t fxt, struct fxt_evbuf *buffer, long size, int kind);
+extern int fxt_setupeventsbuffer(fxt_t fxt, struct fxt_evbuf *buffer, size_t size, int kind);
 extern int fxt_fdwriteevents(fxt_t fxt, int fd, struct fxt_evbuf *buffer);
 
 /******************************************************************************
